# Generated by Django 4.0.5 on 2022-10-28 13:46

from django.conf import settings
import django.contrib.auth.models
import django.contrib.auth.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import imagekit.models.fields
import openbook_auth.helpers
import openbook_common.validators
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('openbook_common', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('email', models.EmailField(max_length=254, unique=True, verbose_name='email address')),
                ('is_email_verified', models.BooleanField(default=False)),
                ('are_guidelines_accepted', models.BooleanField(default=False)),
                ('is_deleted', models.BooleanField(default=False, verbose_name='is deleted')),
                ('visibility', models.CharField(choices=[('P', 'Public'), ('T', 'Private'), ('O', 'Okuna')], default='O', editable=False, max_length=2)),
                ('username', models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 36 characters or fewer. Letters, digits and _ only.', max_length=36, unique=True, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='username')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('invite_count', models.SmallIntegerField(default=0)),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='UserProfile',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(db_index=True, max_length=192, null=True, validators=[openbook_common.validators.name_characters_validator], verbose_name='name')),
                ('last_name', models.CharField(blank=True, db_index=True, max_length=192, null=True, validators=[openbook_common.validators.name_characters_validator], verbose_name='last name')),
                ('pronouns', models.CharField(blank=True, max_length=192, null=True, verbose_name='pronouns')),
                ('location', models.CharField(blank=True, max_length=192, null=True, verbose_name='location')),
                ('engagement_level', models.CharField(choices=[('ENGAGED', 'Engaged'), ('INTERESTED', 'Interested'), ('INITIATOR', 'Initiator')], max_length=10, null=True, verbose_name='engagement level')),
                ('interests', models.JSONField(blank=True, default=list, null=True)),
                ('sdgs', models.JSONField(blank=True, default=list, null=True)),
                ('skills', models.JSONField(blank=True, default=list, null=True)),
                ('is_of_legal_age', models.BooleanField(default=False)),
                ('avatar', imagekit.models.fields.ProcessedImageField(null=True, upload_to=openbook_auth.helpers.upload_to_user_avatar_directory, verbose_name='avatar')),
                ('cover', imagekit.models.fields.ProcessedImageField(null=True, upload_to=openbook_auth.helpers.upload_to_user_cover_directory, verbose_name='cover')),
                ('about_me', models.TextField(max_length=3000, null=True, verbose_name='about me')),
                ('url', models.URLField(null=True, verbose_name='url')),
                ('followers_count_visible', models.BooleanField(default=False, verbose_name='followers count visible')),
                ('community_posts_visible', models.BooleanField(default=True, verbose_name='community posts visible')),
                ('badges', models.ManyToManyField(related_name='users_profiles', to='openbook_common.badge')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='profile', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'user profile',
                'verbose_name_plural': 'users profiles',
            },
        ),
        migrations.CreateModel(
            name='UserNotificationsSubscription',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('new_post_notifications', models.BooleanField(default=False)),
                ('subscriber', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='user_notifications_subscriptions', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='notifications_subscribers', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='UserNotificationsSettings',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('post_comment_notifications', models.BooleanField(default=True, verbose_name='post comment notifications')),
                ('post_comment_reply_notifications', models.BooleanField(default=True, verbose_name='post comment reply notifications')),
                ('post_reaction_notifications', models.BooleanField(default=True, verbose_name='post reaction notifications')),
                ('follow_notifications', models.BooleanField(default=True, verbose_name='follow notifications')),
                ('follow_request_notifications', models.BooleanField(default=True, verbose_name='follow request notifications')),
                ('follow_request_approved_notifications', models.BooleanField(default=True, verbose_name='follow request approved notifications')),
                ('connection_request_notifications', models.BooleanField(default=True, verbose_name='connection request notifications')),
                ('connection_confirmed_notifications', models.BooleanField(default=True, verbose_name='connection confirmed notifications')),
                ('community_invite_notifications', models.BooleanField(default=True, verbose_name='community invite notifications')),
                ('community_new_post_notifications', models.BooleanField(default=True, verbose_name='community new post notifications')),
                ('user_new_post_notifications', models.BooleanField(default=True, verbose_name='user new post notifications')),
                ('post_comment_reaction_notifications', models.BooleanField(default=True, verbose_name='post comment reaction notifications')),
                ('post_comment_user_mention_notifications', models.BooleanField(default=True, verbose_name='post comment user mention notifications')),
                ('post_user_mention_notifications', models.BooleanField(default=True, verbose_name='post user mention notifications')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='notifications_settings', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='UserBlock',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('blocked_user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='blocked_by_users', to=settings.AUTH_USER_MODEL)),
                ('blocker', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='user_blocks', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
